==> nextcloud-app-contacts-2.1.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/pl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Download" : "Ściągnij",
    "Copy link" : "Skopiuj link",
    "Click to copy the link to your clipboard" : "Kliknij, aby skopiować link do schowka",
    "Toggle sharing" : "Przełącz udostępnianie",
    "Delete" : "Skasuj",
    "Rename" : "Zmień nazwę",
    "Share with users or groups" : "Udostępnij użytkownikom lub grupom",
    "can edit" : "może edytować",
    "Close" : "Zamknij",
    "Enabled" : "Włączone",
    "Disabled" : "Wyłączone",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Nie wspierane!",
    "Press ⌘-C to copy." : "Aby skopiować wciśnij ⌘-C.",
    "Press Ctrl-C to copy." : "Aby skopiować wciśnij Ctrl-C.",
    "Address book name" : "Nazwa książki adresowej",
    "Only these special characters are allowed: -_.!?#|()" : "Tylko te znaki specjalne są dozwolone: -_.!?#|()",
    "Address book could not be created." : "Nie można utworzyć książki adresowej.",
    "The selected image is too big (max 1MB)" : "Wybrany plik jest zbyt duży (maks. 1 MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Karta kontaktu jest uszkodzona i musi być naprawiona. Sprawdź dane i zapisz, aby zmienić dane na stałe.",
    "No contacts in here" : "Nie ma tu żadnych kontaktów",
    "Name" : "Nazwa",
    "Organization" : "Organizacja",
    "Title" : "Tytuł",
    "Add field …" : "Dodaj pole ...",
    "Save changes" : "Zapisz zmiany",
    "Address book" : "Książka adresowa",
    "Loading contacts …" : "Ładowanie kontaktów ...",
    "Import into" : "Importuj do",
    "Importing..." : "Importowanie...",
    "Select your addressbook" : "Wybierz książkę adresową",
    "Import is disabled because no writable address book had been found." : "Import wyłączony, ponieważ nie znaleziono książki adresowej do zapisu.",
    "No search result for {query}" : "Brak wyników wyszukiwania dla zapytania {query}",
    "All contacts" : "Wszystkie kontakty",
    "Post office box" : "Skrytka pocztowa",
    "Postal code" : "Kod pocztowy",
    "City" : "Miasto",
    "State or province" : "Województwo ",
    "Country" : "Kraj",
    "Address" : "Adres",
    "(new group)" : "(nowa grupa)",
    "Last name" : "Nazwisko",
    "First name" : "Imię",
    "Additional names" : "Dodatkowe nazwy",
    "Prefix" : "Przedrostek",
    "Suffix" : "Przyrostek",
    "Importing into" : "Importowanie do",
    "New contact" : "Nowy kontakt",
    "Not grouped" : "Nie zgrupowane",
    "Sort by" : "Sortowanie po",
    "There is no address book available to create a contact." : "Brak książki adresowej aby utworzyć kontakt.",
    "{addressbook} shared by {owner}" : "Książka {addressbook} udostępniona przez {owner}",
    "Contact not found." : "Nie znaleziono kontaktu.",
    "You don't have permission to write to this addressbook." : "Nie masz uprawnień do zapisu dla tej książki adresowej.",
    "Contact could not be created." : "Nie można utworzyć kontaktu",
    "No contacts in file. Only vCard files are allowed." : "Nie znaleziono kontaktów w pliku. Dozwolone są tylko pliki vCard.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Wspierane są tylko vCard w wersji 4.0 (RFC6350) lub 3.0 (RFC2426).",
    "Contact could not be moved." : "Nie udało się przenieść kontaktu",
    "Contact could not be saved." : "Nie udało się zapisać kontaktu.",
    "Waiting for the server to be ready…" : "Czekam, aż serwer będzie gotowy...",
    "Importing…" : "Importowanie...",
    "Display name" : "Wyświetlana nazwa",
    "Nickname" : "Pseudonim",
    "Detailed name" : "Szczegółowa nazwa",
    "Notes" : "Notatki",
    "Website" : "Strona WWW",
    "Federated Cloud ID" : "ID Chmury Stowarzyszonej",
    "Home" : "Dom",
    "Work" : "Praca",
    "Other" : "Inne",
    "Groups" : "Grupy",
    "Birthday" : "Urodziny",
    "Anniversary" : "Rocznica",
    "Date of death" : "Data śmierci",
    "Email" : "E-mail",
    "Instant messaging" : "Wiadomości błyskawiczne",
    "Phone" : "Telefon",
    "Mobile" : "Komórka",
    "Work mobile" : "Numer służbowy",
    "Fax" : "Faks",
    "Fax home" : "Faks domowy",
    "Fax work" : "Faks w pracy",
    "Pager" : "Pager",
    "Voice" : "Połączenie głosowe",
    "Car" : "Samochód",
    "Work pager" : "Pager służbowy",
    "Social network" : "Sieć społecznościowa",
    "Relationship" : "Relacja",
    "Spouse" : "Partner",
    "Child" : "Dziecko",
    "Mother" : "Matka",
    "Father" : "Ojciec",
    "Parent" : "Rodzic",
    "Brother" : "Brat",
    "Sister" : "Siostra",
    "Relative" : "Pokrewieństwo",
    "Friend" : "Przyjaciel",
    "Colleague" : "Kolega/Koleżanka",
    "Manager" : "Menadżer",
    "Assistant" : "Asystent",
    "Gender" : "Płeć",
    "Female" : "Kobieta",
    "Male" : "Mężczyzna",
    "Details" : "Szczegóły",
    "Settings" : "Ustawienia"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-app-contacts-2.1.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/contacts/l10n/pl.js <==
OC.L10N.register(
    "contacts",
    {
    "Contacts" : "Kontakty",
    "Download" : "Ściągnij",
    "Copy link" : "Skopiuj link",
    "Click to copy the link to your clipboard" : "Kliknij, aby skopiować link do schowka",
    "Toggle sharing" : "Przełącz udostępnianie",
    "Delete" : "Skasuj",
    "Rename" : "Zmień nazwę",
    "Share with users or groups" : "Udostępnij użytkownikom lub grupom",
    "can edit" : "może edytować",
    "Close" : "Zamknij",
    "Enabled" : "Włączone",
    "Disabled" : "Wyłączone",
    "Copied!" : "Skopiowano!",
    "Not supported!" : "Nie wspierane!",
    "Press ⌘-C to copy." : "Aby skopiować wciśnij ⌘-C.",
    "Press Ctrl-C to copy." : "Aby skopiować wciśnij Ctrl-C.",
    "Address book name" : "Nazwa książki adresowej",
    "Only these special characters are allowed: -_.!?#|()" : "Tylko te znaki specjalne są dozwolone: -_.!?#|()",
    "Address book could not be created." : "Nie można utworzyć książki adresowej.",
    "Upload new image" : "Wyślij nowe zdjęcie",
    "The selected image is too big (max 1MB)" : "Wybrany plik jest zbyt duży (maks. 1 MB)",
    "This card is corrupted and has been fixed. Please check the data and trigger a save to make the changes permanent." : "Karta kontaktu jest uszkodzona i musi być naprawiona. Sprawdź dane i zapisz, aby zmienić dane na stałe.",
    "No contacts in here" : "Nie ma tu żadnych kontaktów",
    "Name" : "Nazwa",
    "Organization" : "Organizacja",
    "Title" : "Tytuł",
    "Add field …" : "Dodaj pole ...",
    "Save changes" : "Zapisz zmiany",
    "Address book" : "Książka adresowa",
    "Loading contacts …" : "Ładowanie kontaktów ...",
    "Import into" : "Importuj do",
    "Importing..." : "Importowanie...",
    "Select your addressbook" : "Wybierz książkę adresową",
    "Import is disabled because no writable address book had been found." : "Import wyłączony, ponieważ nie znaleziono książki adresowej do zapisu.",
    "No search result for {query}" : "Brak wyników wyszukiwania dla zapytania {query}",
    "All contacts" : "Wszystkie kontakty",
    "Post office box" : "Skrytka pocztowa",
    "Postal code" : "Kod pocztowy",
    "City" : "Miasto",
    "State or province" : "Województwo ",
    "Country" : "Kraj",
    "Address" : "Adres",
    "(new group)" : "(nowa grupa)",
    "Last name" : "Nazwisko",
    "First name" : "Imię",
    "Additional names" : "Dodatkowe nazwy",
    "Prefix" : "Przedrostek",
    "Suffix" : "Przyrostek",
    "Importing into" : "Importowanie do",
    "New contact" : "Nowy kontakt",
    "Not grouped" : "Nie zgrupowane",
    "Sort by" : "Sortowanie po",
    "There is no address book available to create a contact." : "Brak książki adresowej aby utworzyć kontakt.",
    "{addressbook} shared by {owner}" : "Książka {addressbook} udostępniona przez {owner}",
    "Contact not found." : "Nie znaleziono kontaktu.",
    "You don't have permission to write to this addressbook." : "Nie masz uprawnień do zapisu dla tej książki adresowej.",
    "Contact could not be created." : "Nie można utworzyć kontaktu",
    "No contacts in file. Only vCard files are allowed." : "Nie znaleziono kontaktów w pliku. Dozwolone są tylko pliki vCard.",
    "Only vCard version 4.0 (RFC6350) or version 3.0 (RFC2426) are supported." : "Wspierane są tylko vCard w wersji 4.0 (RFC6350) lub 3.0 (RFC2426).",
    "Contact could not be moved." : "Nie udało się przenieść kontaktu",
    "Contact could not be saved." : "Nie udało się zapisać kontaktu.",
    "Waiting for the server to be ready…" : "Czekam, aż serwer będzie gotowy...",
    "Importing…" : "Importowanie...",
    "Display name" : "Wyświetlana nazwa",
    "Nickname" : "Pseudonim",
    "Detailed name" : "Szczegółowa nazwa",
    "Notes" : "Notatki",
    "Website" : "Strona WWW",
    "Federated Cloud ID" : "ID Chmury Stowarzyszonej",
    "Home" : "Dom",
    "Work" : "Praca",
    "Other" : "Inne",
    "Groups" : "Grupy",
    "Birthday" : "Urodziny",
    "Anniversary" : "Rocznica",
    "Date of death" : "Data śmierci",
    "Email" : "E-mail",
    "Instant messaging" : "Wiadomości błyskawiczne",
    "Phone" : "Telefon",
    "Mobile" : "Komórka",
    "Work mobile" : "Numer służbowy",
    "Fax" : "Faks",
    "Fax home" : "Faks domowy",
    "Fax work" : "Faks w pracy",
    "Pager" : "Pager",
    "Voice" : "Połączenie głosowe",
    "Car" : "Samochód",
    "Work pager" : "Pager służbowy",
    "Social network" : "Sieć społecznościowa",
    "Relationship" : "Relacja",
    "Specify a relationship between you and the entity represented by this vCard." : "Wskaż relacje między Tobą a osobą reprezentowaną w tym vCard.",
    "Spouse" : "Partner",
    "Child" : "Dziecko",
    "Mother" : "Matka",
    "Father" : "Ojciec",
    "Parent" : "Rodzic",
    "Brother" : "Brat",
    "Sister" : "Siostra",
    "Relative" : "Pokrewieństwo",
    "Friend" : "Przyjaciel",
    "Colleague" : "Kolega/Koleżanka",
    "Manager" : "Menadżer",
    "Assistant" : "Asystent",
    "Related" : "Powiązany",
    "Specify a relationship between another entity and the entity represented by this vCard." : "Wskaż relacje między inną osobą a osobą reprezentowaną w tym vCard.",
    "Contact" : "Kontakt",
    "Agent" : "Agent",
    "Emergency" : "Nagła pomoc",
    "Co-worker" : "Współpracownik",
    "Gender" : "Płeć",
    "Female" : "Kobieta",
    "Male" : "Mężczyzna",
    "Details" : "Szczegóły",
    "Settings" : "Ustawienia"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
